@@ -17,12 +17,16 @@
 package spx2
 
 const (
-	Gop_sched = "Sched"
+	Gop_sched  = "Sched"
+	Gop_sprite = "Sprite"
 )
 
 type Game struct {
 }
 
+func (p *Game) Main() {
+}
+
 type Sprite struct {
 }
 
